<template>
  <a-modal
    :title='title'
    :width='1050'
    :visible='visible'
    :maskClosable='false'
    :confirmLoading='confirmLoading'
    :okButtonProps='{ props: {disabled: disableSubmit} }'
    @ok='handleOk'
    @cancel='handleCancel'
    cancelText='关闭'
  >

    <a-spin :spinning='confirmLoading'>
      <a-form :form='form'>


        <a-row>
          <a-col :span='24'>
            <a-form-item
              label='维保专业编码'
              :labelCol='labelCol'
              :wrapperCol='wrapperCol'
            >
              <a-input
                allow-clear
                :placeholder="'将由系统自动生成'"
                v-decorator="['num', validatorRules.num ]"
                disabled
              />
            </a-form-item>
          </a-col>
          <a-col :span='24'>
            <a-form-item
              label='维保专业名称'
              :labelCol='labelCol'
              :wrapperCol='wrapperCol'
            >
              <a-input
                allow-clear

                :placeholder="'请输入维保专业名称'"
                v-decorator="['name', validatorRules.name ]"
              />
            </a-form-item>
          </a-col>
        </a-row>

        <a-row>
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="备注"
            >
              <a-textarea
                allow-clear
                :placeholder="请输入备注"
                v-model="model.remark"
              />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>

    <template slot='footer'>
      <a-button
        :style="{marginRight: '8px'}"
        @click='handleCancel'
      >
        关闭
      </a-button>
      <a-button
        :disabled='disableSubmit || confirmLoading'
        :loading='confirmLoading'
        @click='handleOk'
        type='primary'
      >确定
      </a-button>
      <!-- icon="save" -->
    </template>

  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { getAction,postAction, requestPut } from '@/api/manage'
import { duplicateCheck } from '@/api/api'

export default {
  name: 'MaintenanceSpecialtyModal',
  data() {
    return {
      title: '操作',
      visible: false,
      codeDisable: true,
      disableSubmit: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        num: {
          rules: [
            { required: true, message: '请输入维保专业编号!' },
            { min: 2, max: 30, message: '长度在 2 到 30 个字符', trigger: 'blur' },
            { validator: this.validateNum }
          ]
        },
        name: {
          rules: [
            { required: true, message: '请输入维保专业编号!' },
            { min: 2, max: 30, message: '长度在 2 到 30 个字符', trigger: 'blur' },
            { validator: this.validateName }
          ]
        },

        remark: {
          rules: [
            { min: 0, max: 100, message: '长度不超过 100 个字符', trigger: 'blur' }
          ]
        }
      },
      url: {
        add: '/maintenanceSpecialty/maintenanceSpecialty/add',
        edit: '/maintenanceSpecialty/maintenanceSpecialty/edit',
        queryById: '/maintenanceSpecialty/maintenanceSpecialty/queryById',
        getNum: '/eam/sysIdentity/getNumNew',
      },
      //新增、编辑、删除、批量删除操作改变数据后刷新关联的组件的监听属性
      alterFlag: ''
    }
  },
  created() {
  },
  methods: {

    add(record) {
      this.edit(record)
    },

    edit(record) {
      this.form.resetFields()
      this.model = Object.assign({}, record)
      this.visible = true
      this.disableSubmit = false
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'num', 'name', 'remark'))
      })
      if (this.model.id) {
        this.codeDisable = true
      } else {
        this.codeDisable = false
        this.$nextTick(() => {
          getAction(this.url.getNum, { type: 'MaintenanceSpecialty', length: '4' }).then((res) => {
            if (res.success) {
              this.form.setFieldsValue({ num: res.message });
            }
          })
        });
      }
    },

    close() {
      this.$emit('close')
      this.visible = false
    },

    handleOk() {
      const that = this
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true
          let formData = Object.assign(this.model, values)
          let obj
          if (!this.model.id) {
            obj = postAction(this.url.add, formData)
          } else {
            obj = requestPut(this.url.edit, formData, { id: this.model.id })
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok')
              that.alterFlag = new Date()
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        }
      })
    },

    handleCancel() {
      this.close()
    },

    //验证 编号
    validateNum(rule, value, callback) {
      var params = {
        tableName: 'mom_eam_maintenance_specialty',
        fieldName: 'num',
        fieldVal: value,
        dataId: this.model.id,
        //数据库中存在字段del_flag并使用该字段作为未删除策略，真删除：false 假删除：true
        delFlag: '0'
      }
      duplicateCheck(params).then((res) => {
        if (res.success) {
          callback()
        } else {
          callback('编号已存在!')
        }
      })
    },

    //验证 名称
    validateName(rule, value, callback) {
      var params = {
        tableName: 'mom_eam_maintenance_specialty',
        fieldName: 'name',
        fieldVal: value,
        dataId: this.model.id,
        //数据库中存在字段del_flag并使用该字段作为未删除策略，真删除：false 假删除：true
        delFlag: '0'
      }
      duplicateCheck(params).then((res) => {
        if (res.success) {
          callback()
        } else {
          callback('名称已存在!')
        }
      })
    }

  }
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>